@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -152,4 +152,11 @@ public interface GFTSPanelI
    *         checkbox
    */
   public String getAutosearchPreference();
+
+  /**
+   * Return the name of the database being searched
+   * 
+   * @return The database name
+   */
+  public String getDbName();
 }
