@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -20,8 +20,6 @@
  */
 package jalview.fts.core;
 
-import java.util.Locale;
-
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStream;
@@ -29,13 +27,13 @@ import java.io.InputStreamReader;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.Locale;
 import java.util.Objects;
 
 import jalview.fts.api.FTSDataColumnI;
 import jalview.fts.api.FTSDataColumnI.FTSDataColumnGroupI;
-import jalview.fts.core.FTSDataColumnPreferences.PreferenceSource;
-import jalview.fts.service.threedbeacons.TDBeaconsFTSRestClient;
 import jalview.fts.api.FTSRestClientI;
+import jalview.fts.core.FTSDataColumnPreferences.PreferenceSource;
 
 /**
  * Base class providing implementation for common methods defined in
@@ -146,7 +144,7 @@ public abstract class FTSRestClient implements FTSRestClientI
               @Override
               public String toString()
               {
-                return lineData[0];
+                return getName();
               }
 
               @Override
