@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -21,18 +21,6 @@
 
 package jalview.fts.core;
 
-import jalview.bin.Cache;
-import jalview.fts.api.FTSDataColumnI;
-import jalview.fts.api.GFTSPanelI;
-import jalview.fts.core.FTSDataColumnPreferences.PreferenceSource;
-import jalview.gui.Desktop;
-import jalview.gui.IProgressIndicator;
-import jalview.gui.JvSwingUtils;
-import jalview.gui.SequenceFetcher;
-import jalview.io.cache.JvCacheableInputBox;
-import jalview.util.MessageManager;
-import jalview.util.Platform;
-
 import java.awt.BorderLayout;
 import java.awt.CardLayout;
 import java.awt.Dimension;
@@ -77,6 +65,18 @@ import javax.swing.event.InternalFrameEvent;
 import javax.swing.table.DefaultTableModel;
 import javax.swing.table.TableColumn;
 
+import jalview.bin.Cache;
+import jalview.fts.api.FTSDataColumnI;
+import jalview.fts.api.GFTSPanelI;
+import jalview.fts.core.FTSDataColumnPreferences.PreferenceSource;
+import jalview.gui.Desktop;
+import jalview.gui.IProgressIndicator;
+import jalview.gui.JvSwingUtils;
+import jalview.gui.SequenceFetcher;
+import jalview.io.cache.JvCacheableInputBox;
+import jalview.util.MessageManager;
+import jalview.util.Platform;
+
 /**
  * This class provides the swing GUI layout for FTS Panel and implements most of
  * the contracts defined in GFSPanelI
@@ -544,7 +544,10 @@ public abstract class GFTSPanel extends JPanel implements GFTSPanelI
           }
           txt_search.getComponent().setToolTipText(
                   JvSwingUtils.wrapTooltip(true, tooltipText));
+          // if (btn_autosearch.isSelected())
           searchAction(true);
+
+          setCmbSearchTargetTooltip();
         }
       }
     });
@@ -678,6 +681,7 @@ public abstract class GFTSPanel extends JPanel implements GFTSPanelI
     pnl_actions.add(btn_cancel);
 
     pnl_results.add(tabbedPane);
+    setCmbSearchTargetTooltip();
     pnl_inputs.add(cmb_searchTarget);
     pnl_inputs.add(txt_search.getComponent());
     pnl_inputs.add(txt_help);
@@ -1085,4 +1089,28 @@ public abstract class GFTSPanel extends JPanel implements GFTSPanelI
 
   @Override
   public abstract void okAction();
+
+  private void setCmbSearchTargetTooltip()
+  {
+    JComboBox<FTSDataColumnI> cmb = getCmbSearchTarget();
+    if (cmb.isEnabled())
+    {
+      boolean isAll = "all"
+              .equalsIgnoreCase(cmb.getSelectedItem().toString());
+      FTSDataColumnI index = (FTSDataColumnI) cmb.getSelectedItem();
+      String indexCode = index.getAltCode();
+      String dbName = getDbName();
+      String message = isAll ? MessageManager
+              .formatMessage("label.search_db_all", new Object[]
+              { dbName })
+              : MessageManager.formatMessage("label.search_db_index",
+                      new Object[]
+                      { dbName, indexCode });
+      cmb.setToolTipText(message);
+    }
+    else
+    {
+      cmb.setToolTipText("");
+    }
+  }
 }
