@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -343,7 +343,7 @@ public class FileParse
     }
     String encoding = _conn.getContentEncoding();
     String contentType = _conn.getContentType();
-    boolean isgzipped = "application/x-gzip".equalsIgnoreCase(contentType)
+    boolean isgzipped = "application/x-gzip".equalsIgnoreCase(contentType) || contentType.endsWith("gzip")
             || "gzip".equals(encoding);
     Exception e = null;
     InputStream inputStream = _conn.getInputStream();
