@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -219,7 +219,7 @@ public class StockholmFile extends AlignFile
     if (!r.search(nextLine()))
     {
       throw new IOException(MessageManager
-              .getString("exception.stockholm_invalid_format"));
+			    .getString("exception.stockholm_invalid_format") +" ("+r+")");
     }
     else
     {
