@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -29,12 +29,7 @@ public class PfamFull extends Pfam
   public PfamFull()
   {
     super();
-  }
-
-  @Override
-  public String getURLSuffix()
-  {
-    return "/alignment/full" + GZIPPED;
+    alignmentType = FULL;
   }
 
   /*
