@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -31,12 +31,7 @@ public class PfamSeed extends Pfam
   public PfamSeed()
   {
     super();
-  }
-
-  @Override
-  public String getURLSuffix()
-  {
-    return "/alignment/seed" + GZIPPED;
+    alignmentType = SEED;
   }
 
   /*
