@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -26,6 +26,13 @@ import static org.testng.Assert.assertNotEquals;
 import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
 
+import java.awt.Color;
+import java.util.List;
+
+import org.testng.annotations.BeforeMethod;
+import org.testng.annotations.BeforeTest;
+import org.testng.annotations.Test;
+
 import jalview.api.FeatureColourI;
 import jalview.datamodel.SequenceFeature;
 import jalview.datamodel.SequenceI;
@@ -37,13 +44,6 @@ import jalview.schemes.FeatureColour;
 import jalview.viewmodel.seqfeatures.FeatureRendererModel;
 import jalview.viewmodel.seqfeatures.FeatureRendererModel.FeatureSettingsBean;
 
-import java.awt.Color;
-import java.util.List;
-
-import org.testng.annotations.BeforeMethod;
-import org.testng.annotations.BeforeTest;
-import org.testng.annotations.Test;
-
 /**
  * Unit tests for feature colour determination, including but not limited to
  * <ul>
@@ -162,6 +162,27 @@ public class FeatureColourFinderTest
     assertNull(c);
   }
 
+  /**
+   * Nested features coloured by label - expect the colour of the enclosed
+   * feature
+   */
+  @Test(groups = "Functional")
+  public void testFindFeatureColour_nestedFeatures()
+  {
+    SequenceFeature sf1 = new SequenceFeature("domain", "peptide", 1, 120, 0f, null);
+    seq.addSequenceFeature(sf1);
+    SequenceFeature sf2 = new SequenceFeature("domain", "binding", 10, 20,
+            0f, null);
+    seq.addSequenceFeature(sf2);
+    FeatureColourI fc = new FeatureColour(Color.red);
+    fc.setColourByLabel(true);
+    fr.setColour("domain", fc);
+    fr.featuresAdded();
+    av.setShowSequenceFeatures(true);
+    Color c = finder.findFeatureColour(null, seq, 15);
+    assertEquals(c, fr.getColor(sf2, fc));
+  }
+
   @Test(groups = "Functional")
   public void testFindFeatureColour_multipleFeaturesAtPositionNoTransparency()
   {
