@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.3)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
  * Copyright (C) 2022 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -22,11 +22,11 @@ package jalview.ws.dbsources;
 
 import static org.testng.Assert.assertEquals;
 
-import jalview.bin.Cache;
-
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
+import jalview.bin.Cache;
+
 public class PfamSeedTest
 {
   @BeforeClass(alwaysRun = true)
@@ -38,14 +38,15 @@ public class PfamSeedTest
   @Test(groups = "Functional")
   public void testGetURL()
   {
-    String path = "pfam.xfam.org/family/ABC/alignment/seed/gzipped";
+    String path = "www.ebi.ac.uk/interpro/api/entry/pfam/ABC/?annotation=alignment:seed";
 
     // with default value for domain
     String url = new PfamSeed().getURL(" abc ");
     assertEquals(url, "https://" + path);
 
     // with override in properties
-    Cache.setProperty(Pfam.PFAM_BASEURL_KEY, "http://pfam.xfam.org");
+    Cache.setProperty(Pfam.PFAM_BASEURL_KEY,
+            "http://www.ebi.ac.uk/interpro/api/entry/pfam/$PFAMID$/?annotation=alignment:$ALTYPE$");
     url = new PfamSeed().getURL(" abc ");
     assertEquals(url, "http://" + path);
   }
